@@ -1,6 +1,6 @@
 /* Key encoding and decoding functions
 
-   Copyright (c) 1997-2004, 2008-2011 Free Software Foundation, Inc.
+   Copyright (c) 1997-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -128,7 +128,7 @@ chordtodesc (size_t key)
       if (key <= 0xff && isgraph (key))
         astr_cat_char (as, (int) key);
       else
-        astr_cat (as, astr_fmt ("<%x>", key));
+        astr_cat (as, astr_fmt ("<%x>", (unsigned) key));
     }
 
   return as;
