@@ -1,6 +1,6 @@
 /* Program invocation, startup and shutdown
 
-   Copyright (c) 1997-2012 Free Software Foundation, Inc.
+   Copyright (c) 1997-2014 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -37,12 +37,12 @@
 #include "extern.h"
 
 #define ZILE_COPYRIGHT_STRING \
-  "Copyright (C) 2012 Free Software Foundation, Inc."
+  "Copyright (C) 2014 Free Software Foundation, Inc."
 
 /* The current window; the first window in list. */
-Window *cur_wp = NULL, *head_wp = NULL;
+Window cur_wp = NULL, head_wp = NULL;
 /* The current buffer; the first buffer in list. */
-Buffer *cur_bp = NULL, *head_bp = NULL;
+Buffer cur_bp = NULL, head_bp = NULL;
 
 /* The global editor flags. */
 int thisflag = 0, lastflag = 0;
@@ -111,20 +111,11 @@ struct option longopts[] = {
   {0, 0, 0, 0}
 };
 
-enum {ARG_FUNCTION = 1, ARG_LOADFILE, ARG_FILE};
+enum {arg_function = 1, arg_loadfile, arg_file};
 
 int
 main (int argc, char **argv)
 {
-  int qflag = false;
-  gl_list_t arg_type = gl_list_create_empty (GL_LINKED_LIST,
-                                             NULL, NULL, NULL, false);
-  gl_list_t arg_arg = gl_list_create_empty (GL_LINKED_LIST,
-                                             NULL, NULL, NULL, false);
-  gl_list_t arg_line = gl_list_create_empty (GL_LINKED_LIST,
-                                             NULL, NULL, NULL, false);
-  size_t line = 1;
-
   GC_INIT ();
   set_program_name (argv[0]);
   estr_init ();
@@ -135,6 +126,15 @@ main (int argc, char **argv)
   init_variables ();
   init_eval ();
 
+  int qflag = false;
+  gl_list_t arg_type = gl_list_create_empty (GL_LINKED_LIST,
+                                             NULL, NULL, NULL, false);
+  gl_list_t arg_arg = gl_list_create_empty (GL_LINKED_LIST,
+                                             NULL, NULL, NULL, false);
+  gl_list_t arg_line = gl_list_create_empty (GL_LINKED_LIST,
+                                             NULL, NULL, NULL, false);
+  size_t line = 1;
+
   opterr = 0; /* Don't display errors for unknown options */
   for (;;)
     {
@@ -171,13 +171,13 @@ main (int argc, char **argv)
           qflag = true;
           break;
         case 1:
-          gl_list_add_last (arg_type, (void *) ARG_FUNCTION);
+          gl_list_add_last (arg_type, (void *) arg_function);
           gl_list_add_last (arg_arg, (const void *) astr_new_cstr (optarg));
           gl_list_add_last (arg_line, (void *) 0);
           break;
         case 2:
           {
-            gl_list_add_last (arg_type, (void *) ARG_LOADFILE);
+            gl_list_add_last (arg_type, (void *) arg_loadfile);
             astr as = astr_new_cstr (optarg);
             expand_path (as);
             gl_list_add_last (arg_arg, (const void *) astr_cstr (as));
@@ -218,7 +218,7 @@ main (int argc, char **argv)
             line = strtoul (optarg + 1, NULL, 10);
           else
             {
-              gl_list_add_last (arg_type, (void *) ARG_FILE);
+              gl_list_add_last (arg_type, (void *) arg_file);
               astr as = astr_new_cstr (optarg);
               expand_path (as);
               gl_list_add_last (arg_arg, (const void *) astr_cstr (as));
@@ -243,7 +243,7 @@ main (int argc, char **argv)
   /* Create the `*scratch*' buffer, so that initialisation commands
      that act on a buffer have something to act on. */
   create_scratch_window ();
-  Buffer *scratch_bp = cur_bp;
+  Buffer scratch_bp = cur_bp;
   bprintf ("%s", "\
 ;; This buffer is for notes you don't want to save.\n\
 ;; If you want to create a file, visit that file with C-x C-f,\n\
@@ -264,7 +264,7 @@ main (int argc, char **argv)
   if (gl_list_size (arg_arg) == 0 && minibuf_no_error () &&
       !get_variable_bool ("inhibit-splash-screen"))
     {
-      Buffer *bp = create_auto_buffer ("*GNU " PACKAGE_NAME "*");
+      Buffer bp = create_auto_buffer ("*GNU " PACKAGE_NAME "*");
       switch_to_buffer (bp);
       bprintf ("%s", splash_str);
       set_buffer_readonly (bp, true);
@@ -280,7 +280,7 @@ main (int argc, char **argv)
 
       switch ((ptrdiff_t) gl_list_get_at (arg_type, i))
         {
-        case ARG_FUNCTION:
+        case arg_function:
           {
             le *res = execute_function (arg, 1, false);
             if (res == NULL)
@@ -288,12 +288,12 @@ main (int argc, char **argv)
             ok = res == leT;
             break;
           }
-        case ARG_LOADFILE:
+        case arg_loadfile:
           ok = lisp_loadfile (arg);
           if (!ok)
             minibuf_error ("Cannot open load file: %s\n", arg);
           break;
-        case ARG_FILE:
+        case arg_file:
           {
             ok = find_file (arg);
             if (ok)
@@ -309,9 +309,9 @@ main (int argc, char **argv)
   lastflag |= FLAG_NEED_RESYNC;
 
   /* Set up screen according to number of files loaded. */
-  Buffer *last_bp = NULL;
+  Buffer last_bp = NULL;
   int c = 0;
-  for (Buffer *bp = head_bp; bp; bp = get_buffer_next (bp))
+  for (Buffer bp = head_bp; bp; bp = get_buffer_next (bp))
     {
       /* Last buffer that isn't *scratch*. */
       if (get_buffer_next (bp) && !get_buffer_next (get_buffer_next (bp)))
